# fourier_transforms

Description. 
The package fourier_transforms is used to:
	- Fast Fourier Transform (FFT)
	- Discrete Fourier Transform (DFT)

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install fourier_transforms
```

## Author
Ygor

## License
[MIT](https://choosealicense.com/licenses/mit/)